==> cdk-lambda-subminute-2.0.148-sources.jar: io/github/hsiehshujeng/cdk/lambda/subminute/SubminuteStateMachineProps.java <==
package io.github.hsiehshujeng.cdk.lambda.subminute;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.80.0 (build bce6a1d)", date = "2023-05-10T01:14:30.148Z")
@software.amazon.jsii.Jsii(module = io.github.hsiehshujeng.cdk.lambda.subminute.$Module.class, fqn = "cdk-lambda-subminute.SubminuteStateMachineProps")
@software.amazon.jsii.Jsii.Proxy(SubminuteStateMachineProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SubminuteStateMachineProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * How many times you intent to execute in a minute.
     * <p>
     * Default: 6
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getFrequency();

    /**
     * Seconds for an interval, the product of `frequency` and `intervalTime` should be approximagely 1 minute.
     * <p>
     * Default: 10
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getIntervalTime();

    /**
     * the iterator Lambda function for the target Lambda function.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction getIteratorFunction();

    /**
     * the name of the state machine.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getStateMachineName();

    /**
     * the Lambda function that executes your intention.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction getTargetFunction();

    /**
     * @return a {@link Builder} of {@link SubminuteStateMachineProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SubminuteStateMachineProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SubminuteStateMachineProps> {
        java.lang.Number frequency;
        java.lang.Number intervalTime;
        software.amazon.awscdk.services.lambda.IFunction iteratorFunction;
        java.lang.String stateMachineName;
        software.amazon.awscdk.services.lambda.IFunction targetFunction;

        /**
         * Sets the value of {@link SubminuteStateMachineProps#getFrequency}
         * @param frequency How many times you intent to execute in a minute. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder frequency(java.lang.Number frequency) {
            this.frequency = frequency;
            return this;
        }

        /**
         * Sets the value of {@link SubminuteStateMachineProps#getIntervalTime}
         * @param intervalTime Seconds for an interval, the product of `frequency` and `intervalTime` should be approximagely 1 minute. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder intervalTime(java.lang.Number intervalTime) {
            this.intervalTime = intervalTime;
            return this;
        }

        /**
         * Sets the value of {@link SubminuteStateMachineProps#getIteratorFunction}
         * @param iteratorFunction the iterator Lambda function for the target Lambda function. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder iteratorFunction(software.amazon.awscdk.services.lambda.IFunction iteratorFunction) {
            this.iteratorFunction = iteratorFunction;
            return this;
        }

        /**
         * Sets the value of {@link SubminuteStateMachineProps#getStateMachineName}
         * @param stateMachineName the name of the state machine. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stateMachineName(java.lang.String stateMachineName) {
            this.stateMachineName = stateMachineName;
            return this;
        }

        /**
         * Sets the value of {@link SubminuteStateMachineProps#getTargetFunction}
         * @param targetFunction the Lambda function that executes your intention. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetFunction(software.amazon.awscdk.services.lambda.IFunction targetFunction) {
            this.targetFunction = targetFunction;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SubminuteStateMachineProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SubminuteStateMachineProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SubminuteStateMachineProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SubminuteStateMachineProps {
        private final java.lang.Number frequency;
        private final java.lang.Number intervalTime;
        private final software.amazon.awscdk.services.lambda.IFunction iteratorFunction;
        private final java.lang.String stateMachineName;
        private final software.amazon.awscdk.services.lambda.IFunction targetFunction;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.frequency = software.amazon.jsii.Kernel.get(this, "frequency", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.intervalTime = software.amazon.jsii.Kernel.get(this, "intervalTime", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.iteratorFunction = software.amazon.jsii.Kernel.get(this, "iteratorFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.IFunction.class));
            this.stateMachineName = software.amazon.jsii.Kernel.get(this, "stateMachineName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.targetFunction = software.amazon.jsii.Kernel.get(this, "targetFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.IFunction.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.frequency = java.util.Objects.requireNonNull(builder.frequency, "frequency is required");
            this.intervalTime = java.util.Objects.requireNonNull(builder.intervalTime, "intervalTime is required");
            this.iteratorFunction = java.util.Objects.requireNonNull(builder.iteratorFunction, "iteratorFunction is required");
            this.stateMachineName = java.util.Objects.requireNonNull(builder.stateMachineName, "stateMachineName is required");
            this.targetFunction = java.util.Objects.requireNonNull(builder.targetFunction, "targetFunction is required");
        }

        @Override
        public final java.lang.Number getFrequency() {
            return this.frequency;
        }

        @Override
        public final java.lang.Number getIntervalTime() {
            return this.intervalTime;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.IFunction getIteratorFunction() {
            return this.iteratorFunction;
        }

        @Override
        public final java.lang.String getStateMachineName() {
            return this.stateMachineName;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.IFunction getTargetFunction() {
            return this.targetFunction;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("frequency", om.valueToTree(this.getFrequency()));
            data.set("intervalTime", om.valueToTree(this.getIntervalTime()));
            data.set("iteratorFunction", om.valueToTree(this.getIteratorFunction()));
            data.set("stateMachineName", om.valueToTree(this.getStateMachineName()));
            data.set("targetFunction", om.valueToTree(this.getTargetFunction()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("cdk-lambda-subminute.SubminuteStateMachineProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SubminuteStateMachineProps.Jsii$Proxy that = (SubminuteStateMachineProps.Jsii$Proxy) o;

            if (!frequency.equals(that.frequency)) return false;
            if (!intervalTime.equals(that.intervalTime)) return false;
            if (!iteratorFunction.equals(that.iteratorFunction)) return false;
            if (!stateMachineName.equals(that.stateMachineName)) return false;
            return this.targetFunction.equals(that.targetFunction);
        }

        @Override
        public final int hashCode() {
            int result = this.frequency.hashCode();
            result = 31 * result + (this.intervalTime.hashCode());
            result = 31 * result + (this.iteratorFunction.hashCode());
            result = 31 * result + (this.stateMachineName.hashCode());
            result = 31 * result + (this.targetFunction.hashCode());
            return result;
        }
    }
}

==> cdk-lambda-subminute-2.0.417-sources.jar: io/github/hsiehshujeng/cdk/lambda/subminute/SubminuteStateMachineProps.java <==
package io.github.hsiehshujeng.cdk.lambda.subminute;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-03-30T01:02:55.414Z")
@software.amazon.jsii.Jsii(module = io.github.hsiehshujeng.cdk.lambda.subminute.$Module.class, fqn = "cdk-lambda-subminute.SubminuteStateMachineProps")
@software.amazon.jsii.Jsii.Proxy(SubminuteStateMachineProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface SubminuteStateMachineProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * How many times you intent to execute in a minute.
     * <p>
     * Default: 6
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getFrequency();

    /**
     * Seconds for an interval, the product of <code>frequency</code> and <code>intervalTime</code> should be approximagely 1 minute.
     * <p>
     * Default: 10
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getIntervalTime();

    /**
     * the iterator Lambda function for the target Lambda function.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction getIteratorFunction();

    /**
     * the name of the state machine.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getStateMachineName();

    /**
     * the Lambda function that executes your intention.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction getTargetFunction();

    /**
     * @return a {@link Builder} of {@link SubminuteStateMachineProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SubminuteStateMachineProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<SubminuteStateMachineProps> {
        java.lang.Number frequency;
        java.lang.Number intervalTime;
        software.amazon.awscdk.services.lambda.IFunction iteratorFunction;
        java.lang.String stateMachineName;
        software.amazon.awscdk.services.lambda.IFunction targetFunction;

        /**
         * Sets the value of {@link SubminuteStateMachineProps#getFrequency}
         * @param frequency How many times you intent to execute in a minute. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder frequency(java.lang.Number frequency) {
            this.frequency = frequency;
            return this;
        }

        /**
         * Sets the value of {@link SubminuteStateMachineProps#getIntervalTime}
         * @param intervalTime Seconds for an interval, the product of <code>frequency</code> and <code>intervalTime</code> should be approximagely 1 minute. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder intervalTime(java.lang.Number intervalTime) {
            this.intervalTime = intervalTime;
            return this;
        }

        /**
         * Sets the value of {@link SubminuteStateMachineProps#getIteratorFunction}
         * @param iteratorFunction the iterator Lambda function for the target Lambda function. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder iteratorFunction(software.amazon.awscdk.services.lambda.IFunction iteratorFunction) {
            this.iteratorFunction = iteratorFunction;
            return this;
        }

        /**
         * Sets the value of {@link SubminuteStateMachineProps#getStateMachineName}
         * @param stateMachineName the name of the state machine. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stateMachineName(java.lang.String stateMachineName) {
            this.stateMachineName = stateMachineName;
            return this;
        }

        /**
         * Sets the value of {@link SubminuteStateMachineProps#getTargetFunction}
         * @param targetFunction the Lambda function that executes your intention. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetFunction(software.amazon.awscdk.services.lambda.IFunction targetFunction) {
            this.targetFunction = targetFunction;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SubminuteStateMachineProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public SubminuteStateMachineProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SubminuteStateMachineProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SubminuteStateMachineProps {
        private final java.lang.Number frequency;
        private final java.lang.Number intervalTime;
        private final software.amazon.awscdk.services.lambda.IFunction iteratorFunction;
        private final java.lang.String stateMachineName;
        private final software.amazon.awscdk.services.lambda.IFunction targetFunction;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.frequency = software.amazon.jsii.Kernel.get(this, "frequency", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.intervalTime = software.amazon.jsii.Kernel.get(this, "intervalTime", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.iteratorFunction = software.amazon.jsii.Kernel.get(this, "iteratorFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.IFunction.class));
            this.stateMachineName = software.amazon.jsii.Kernel.get(this, "stateMachineName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.targetFunction = software.amazon.jsii.Kernel.get(this, "targetFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.IFunction.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.frequency = java.util.Objects.requireNonNull(builder.frequency, "frequency is required");
            this.intervalTime = java.util.Objects.requireNonNull(builder.intervalTime, "intervalTime is required");
            this.iteratorFunction = java.util.Objects.requireNonNull(builder.iteratorFunction, "iteratorFunction is required");
            this.stateMachineName = java.util.Objects.requireNonNull(builder.stateMachineName, "stateMachineName is required");
            this.targetFunction = java.util.Objects.requireNonNull(builder.targetFunction, "targetFunction is required");
        }

        @Override
        public final java.lang.Number getFrequency() {
            return this.frequency;
        }

        @Override
        public final java.lang.Number getIntervalTime() {
            return this.intervalTime;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.IFunction getIteratorFunction() {
            return this.iteratorFunction;
        }

        @Override
        public final java.lang.String getStateMachineName() {
            return this.stateMachineName;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.IFunction getTargetFunction() {
            return this.targetFunction;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("frequency", om.valueToTree(this.getFrequency()));
            data.set("intervalTime", om.valueToTree(this.getIntervalTime()));
            data.set("iteratorFunction", om.valueToTree(this.getIteratorFunction()));
            data.set("stateMachineName", om.valueToTree(this.getStateMachineName()));
            data.set("targetFunction", om.valueToTree(this.getTargetFunction()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("cdk-lambda-subminute.SubminuteStateMachineProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SubminuteStateMachineProps.Jsii$Proxy that = (SubminuteStateMachineProps.Jsii$Proxy) o;

            if (!frequency.equals(that.frequency)) return false;
            if (!intervalTime.equals(that.intervalTime)) return false;
            if (!iteratorFunction.equals(that.iteratorFunction)) return false;
            if (!stateMachineName.equals(that.stateMachineName)) return false;
            return this.targetFunction.equals(that.targetFunction);
        }

        @Override
        public final int hashCode() {
            int result = this.frequency.hashCode();
            result = 31 * result + (this.intervalTime.hashCode());
            result = 31 * result + (this.iteratorFunction.hashCode());
            result = 31 * result + (this.stateMachineName.hashCode());
            result = 31 * result + (this.targetFunction.hashCode());
            return result;
        }
    }
}
